aboutsummaryrefslogtreecommitdiff
path: root/src/config.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/config.py')
-rw-r--r--src/config.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/config.py b/src/config.py
index ca697f5..59c7dad 100644
--- a/src/config.py
+++ b/src/config.py
@@ -6,7 +6,7 @@
# By: charles <charles.cabergs@gmail.com> +#+ +:+ +#+ #
# +#+#+#+#+#+ +#+ #
# Created: 2020/07/15 18:24:19 by charles #+# #+# #
-# Updated: 2020/09/11 12:21:14 by charles ### ########.fr #
+# Updated: 2020/09/11 14:21:14 by charles ### ########.fr #
# #
# ############################################################################ #
@@ -26,8 +26,8 @@ MINISHELL_DIR = ".."
# minishell executable
MINISHELL_EXEC = "minishell"
-# build minishell before executing the test if set to True
-MINISHELL_BUILD = True
+# make minishell before executing the test if set to True
+MINISHELL_MAKE = True
# path to reference shell (shell which will be compared minishell)
# has to support the -c option (sh, bash and zsh support it)